Security Advisories (1)
CVE-2026-8376 (2026-05-25)

Perl versions through 5.43.10 have a heap buffer overflow when compiling regular expressions with a repeated fixed string on 32-bit builds. Perl_study_chunk in regcomp_study.c checked the size of the joined substring buffer in characters rather than bytes. For a quantified fixed substring with a large minimum count, the byte length mincount * l could overflow SSize_t, producing an undersized SvGROW allocation; the subsequent copy writes past the end of the buffer. A caller that compiles an attacker-controlled regular expression on a 32-bit perl build triggers a heap buffer overflow at compile time.

NAME

DBM_Filter::compress - filter for DBM_Filter

SYNOPSIS

use SDBM_File; # or DB_File, GDBM_File, NDBM_File, ODBM_File
use DBM_Filter ;

$db = tie %hash, ...
$db->Filter_Push('compress');

DESCRIPTION

This DBM filter will compress all data before it is written to the database and uncompressed it on reading.

A fatal error will be thrown if the Compress::Zlib module is not available.

SEE ALSO

DBM_Filter, perldbmfilter, Compress::Zlib

AUTHOR

Paul Marquess pmqs@cpan.org